function plot_orbit_diagram(map)
% plot_orbit_diagram('logistic')
% plot_orbit_diagram('tent')
% plot_orbit_diagram('sinmap')
% plot_orbit_diagram('feigenbaum')

if nargin < 1
  map = 'logistic';
end

N0 = 1000;
N = 200;
npts = 1000;

switch lower(map)
 case 'logistic'
  r = linspace(0,4,npts);
  x = rand(size(r));
  xm = .5;
 case 'tent'
  r = linspace(0,2,npts);
  x = rand(size(r));
  xm = [];
 case 'sinmap'
  r = linspace(0,1,npts);
  x = rand(size(r));
  xm = .5;
 case 'feigenbaum'
  % r is in [0,2], x in [-sqrt(2*r),sqrt(2*r)].
  r = linspace(0,2,npts);
  x = sqrt(2*r).*(2*rand(size(r))-1);
  xm = 0;
end

for it = 1:N0
  x = feval(map,x,r);
end

figure(1)
clf
hold on

for it = 1:N
  x = feval(map,x,r);
  plot(r,x,'.','MarkerSize',1)
end

if ~isempty(xm)
  % Plot line for superstable orbits.
  plot(r,xm,'r-')
end

hold off
axis tight
